<template>
    <Header />
    <section class="bg-light py-5">
        <section class="container">
            <section class="checkout-wizard bg-white theme-shadow my-4">
                <h3 class="fw-bold px-5 py-4 border-bottom mb-0">Checkout</h3>
                <div class="row">
                    <div class="col-8 border-end p-4 ps-5">
                        <div class="border rounded-3 p-4 mb-4">
                            <div class="row">
                                <div class="col-4">
                                    <img :src="course?.thumbnail" width="100%" alt="" height="140px"
                                        class="object-fit-cover rounded-3">
                                </div>
                                <div class="col-8">
                                    <h5>{{ course?.title }}</h5>
                                    <div class="d-flex mt-3 pb-3">
                                        <img :src="course?.instructor?.profile_picture"
                                            class="rounded-circle object-fit-cover me-3" height="30px" width="30px">
                                        <div>
                                            <span class="d-block">{{ course?.instructor?.name }}</span>
                                        </div>

                                    </div>
                                    <div>
                                        <i class="bi bi-star-fill text-warning me-2"></i>
                                        <strong>{{ course?.average_rating }}</strong>
                                        <span class="text-muted ms-2">({{ course?.review_count }} Reviews)</span>
                                        <span class="text-muted mx-1">
                                            <i class="bi bi-dot"></i>
                                        </span>
                                        <span class="text-muted">{{ course?.student_count }} Enrolled</span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="border rounded-3 p-4">
                            <h5 class="mb-4">Order Details</h5>
                            <div class="bg-light rounded-3 p-4">
                                <div class="price-breakdown mb-3">

                                    <div class="d-flex justify-content-between mb-4">
                                        <span>Course Price</span>
                                        <strong>${{ course?.price }}</strong>
                                    </div>
                                    <div class="d-flex justify-content-between mb-4 text-danger">
                                        <span>Discount</span>
                                        <strong>-$0</strong>
                                    </div>
                                    <div class="mb-3">
                                        <span v-if="!showCouponInput" @click="showCouponInput = true"
                                            class="text-primary text-decoration-underline cursor-pointer">Have any
                                            coupon?</span>
                                    </div>
                                    <form @submit.prevent="validateCoupon" v-if="!couponApplied && showCouponInput"
                                        class="bg-white d-flex rounded-3 p-4 mb-3">
                                        <input type="text" v-model="couponCode" class="form-control me-3"
                                            placeholder="Enter coupon code">
                                        <button type="submit" class="btn btn-primary">Apply</button>
                                    </form>

                                    <div v-if="couponApplied" class="d-flex justify-content-between mb-3">
                                        <div>
                                            <i class="ri-checkbox-circle-fill text-success me-1"></i>
                                            <span class="me-3">Coupon Applied</span>
                                            <small
                                                @click="couponApplied = false; showCouponInput = true; couponCode = null"
                                                class="text-success bg-lightgreen px-2 py-1 rounded cursor-pointer">{{
                                                    couponCode }} <i class="ri-edit-line"></i></small>
                                        </div>
                                    </div>
                                </div>

                                <div class="d-flex justify-content-between">
                                    <span>
                                        <span class="fw-bold me-1">Subtotal</span>
                                        <span>(Payable)</span>
                                    </span>
                                    <span class="fw-bold">${{ course?.price }}</span>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="col-4 ps-0 d-flex flex-column">
                        <div class="p-4 pe-5">
                            <div class="d-flex justify-content-between align-items-center mb-4">
                                <h5 class="fw-bold">Payment Method</h5>
                                <small class="bg-lightgreen text-success rounded px-2 py-1">
                                    <i class="ri-shield-check-fill me-1"></i>
                                    100% Secure Payment
                                </small>
                            </div>

                            <div v-for="gateway in masterStore?.masterData?.payment_methods" :key="gateway.id">
                                <div @click="selectedPaymentMethod = gateway.gateway"
                                    :class="'border d-flex justify-content-between align-items-center px-3 mb-3 rounded payment-method mx-auto' + (selectedPaymentMethod == gateway.gateway ? ' selected' : '')">
                                    <img :src="gateway.logo" class="col-3">
                                    <input class="form-check-input" type="radio"
                                        :checked="selectedPaymentMethod == gateway.gateway">
                                </div>
                            </div>
                        </div>

                        <div class="mt-auto border-top p-4">
                            <button @click="initiateTransaction" class="btn btn-primary rounded-pill fw-bold w-100">Pay
                                ${{
                                    grandTotal }}
                                <i class="bi bi-arrow-right float-end"></i>
                            </button>
                        </div>
                    </div>
                </div>
            </section>
        </section>
    </section>
</template>

<script setup>
import { onMounted, ref, watch } from 'vue';
import Header from '../components/Header.vue';
import { useMasterStore } from '@/stores/master';
import { useAuthStore } from '@/stores/auth';
import { useRoute, useRouter } from 'vue-router';
import axios from 'axios';
import Swal from 'sweetalert2';

const masterStore = useMasterStore();
const authStore = useAuthStore();
const route = useRoute()
const router = useRouter();

const course_id = route.params.id
const selectedPaymentMethod = ref('stripe')

const course = ref({});
const discountAmount = ref(0);
const grandTotal = ref(0);
const showCouponInput = ref(false);
const couponCode = ref('');
const couponApplied = ref(false);

watch(() => discountAmount.value, () => {
    grandTotal.value = course.value.price - discountAmount.value;
})

const validateCoupon = async () => {
    try {
        const response = await axios.get(`/coupon/validate`, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': `Bearer ${authStore.authToken}`
            },
            params: {
                coupon_code: couponCode.value
            }
        })

        discountAmount.value = response.data.data.discount;
        couponApplied.value = true;

        Swal.fire({
            icon: 'success',
            title: 'Coupon applied successfully',
            showConfirmButton: false,
            timer: 1500
        })
    } catch (error) {
        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Coupon code is invalid',
            showConfirmButton: false,
            timer: 1500
        })
    }
}

const fetchCourseData = async () => {
    try {
        const response = await axios.get(`/course/show/${course_id}`, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': `Bearer ${authStore.authToken}`
            }
        });
        course.value = response.data.data.course;
        grandTotal.value = course.value.price - discountAmount.value;
    } catch (error) {
        console.error('Error fetching course data:', error);
    }
};

const initiateTransaction = async () => {
    try {
        const response = await axios.get(`/enroll/${course_id}`, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': `Bearer ${authStore.authToken}`
            },
            params: {
                payment_gateway: selectedPaymentMethod.value,
                coupon_code: couponCode.value
            }
        });

        openPaymentPopupWindow(response.data.data.payment_webview_url);
    } catch (error) {
        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: error.response?.data?.message || 'Something went wrong. Please try again.',
        })
    }
};

onMounted(async () => {
    await fetchCourseData();
});


const openPaymentPopupWindow = (url) => {
    let winWidth = 700;
    let winHeight = 700;
    let left = (screen.width / 2) - (winWidth / 2);
    let top = (screen.height / 2) - (winHeight / 2);

    let options = "popup,resizable,height=" + winHeight + ",width=" + winWidth + ",top=" + top + ",left=" + left;

    let win = window.open(url, null, options);

    win.title = "Payment Window Screen - Make Payment";

    win.onload = () => {
        win.title = "Payment Window Screen - Make Payment";
        if (win.closed) {
            console.log('close window');
        }
    };

    win.focus();

    if (win.closed) {
        router.push('/enroll_status?course_id=' + course_id + '&status=' + 'cancel');
        return
    }

    var intervalID = setInterval(trackURLChanges, 1000);
    function trackURLChanges() {
        try {
            const pathname = win.location.pathname;

            var currentPath = pathname.replace(/\/payment\/\d+/, "");

            var setTime = ref(false);

            if (currentPath.includes('payment/cancel')) {
                win.close();
                clearInterval(intervalID);

                router.push('/enroll_status?course_id=' + course_id + '&status=' + 'cancel');
                return
            }

            if (currentPath.includes('payment/success')) {
                win.close();
                clearInterval(intervalID);
                router.push('/enroll_status?course_id=' + course_id + '&status=' + 'success');

                return
            }

            if (currentPath.includes('payment/fail')) {
                win.close();
                clearInterval(intervalID);
                router.push('/enroll_status?course_id=' + course_id + '&status=' + 'fail');

                return
            }

            if (win.closed || !win.location) {
                clearInterval(intervalID);
                win.close();
                router.push('/enroll_status?course_id=' + course_id + '&status=' + 'failed');
            }
        } catch (e) { }
    }

    setTimeout(() => {
        clearInterval(intervalID);
        win.close();
    }, 180000);
};

</script>

<style lang="scss" scoped>
.checkout-wizard {
    border-radius: 2rem;
    box-shadow: 0px 16px 64px 0px #9747FF14;

    .price-breakdown {
        border-bottom: 2px dashed #ccc;
    }

    .payment-method {
        cursor: pointer;

        &:hover {
            border-color: #9E4AED !important;
        }
    }

    .payment-method.selected {
        border-color: #9E4AED !important;
    }
}
</style>
